body {
    background: #F5F5F5;
}

.login-panel {
    left: 50%;
    top: 30%;
    position: absolute;
    margin-left: -250px;
    margin-top: -150px;
    height: 300px;
    width: 500px;
}

.center {
    text-align: center;
}

.logo {
    display: block;
    margin: auto;
}

[class*="-login"] i {
    font-size: 3rem;
    margin: 10px;
}


.fi-at-sign, .fi-key {
    color: #A7A7A7;
}

