<!DOCTYPE html>
<html>
    <head itemscope itemtype="http://schema.org/WebPage">
        <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
        <meta name="viewport" content="initial-scale=1">
        <title>Ella's Kitchen Import Hub</title>
        <!-- Stylesheets -->
        <link rel="stylesheet" href="/static/css/importhub.css" type="text/css" />
        <!-- <link rel="stylesheet" href="/static/css/fonts.css" type="text/css" /> -->
        <!-- Header JS -->
        <script src="/static/js/modernizr.min.js"></script>
    </head>

    <body>
        <p>Thanks for submitting the import. It will be processed as soon as possible. We will email you the results as soon as it finishes.</p>
    </body>
</html>
