<!DOCTYPE html>
<html>
    <head itemscope itemtype="http://schema.org/WebPage">
        <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
        <meta name="viewport" content="initial-scale=1">
        <title>Ella's Kitchen Import Hub</title>
        <!-- Stylesheets -->
        <link id="ellas_module_n_state-css" href="/static/css/foundation.css"  media="all" rel="stylesheet" type="text/css"/>
        <link rel="stylesheet" href="/static/css/importhub.css" type="text/css" />
        <!-- <link rel="stylesheet" href="/static/css/fonts.css" type="text/css" /> -->
        <!-- Header JS -->
        <script src="/static/js/modernizr.min.js"></script>
    </head>

    <body>
        <div class="login-panel">

            <form method="post" enctype="multipart/form-data">{% csrf_token %}

            {{ form.as_p }}

                <div class="row">
                    <div class="large-12 columns">
                        <button type="submit" class="button tiny radius">Go</button>
                    </div>
                </div>
            </form>

        </div>
        <!-- Footer JS -->
        <script src="/static/js/app.js"></script>
    </body>
</html>
